@@ -10,6 +10,7 @@
 """
 
 import os
+import sys
 import difflib
 import htmlentitydefs
 from StringIO import StringIO
@@ -27,17 +28,21 @@ latex_warnfile = StringIO()
 
 ENV_WARNINGS = """\
 WARNING: %(root)s/images.txt:9: Image file not readable: foo.png
-WARNING: %(root)s/images.txt:21: Nonlocal image URI found: http://www.python.org/logo.png
+WARNING: %(root)s/images.txt:23: Nonlocal image URI found: http://www.python.org/logo.png
 WARNING: %(root)s/includes.txt:: (WARNING/2) Encoding 'utf-8' used for reading included \
 file u'wrongenc.inc' seems to be wrong, try giving an :encoding: option
 """
 
 HTML_WARNINGS = ENV_WARNINGS + """\
 WARNING: %(root)s/images.txt:: no matching candidate for image URI u'foo.*'
+WARNING: %(root)s/markup.txt:: invalid index entry u''
+WARNING: %(root)s/markup.txt:: invalid pair index entry u''
+WARNING: %(root)s/markup.txt:: invalid pair index entry u'keyword; '
 """
 
 LATEX_WARNINGS = ENV_WARNINGS + """\
 WARNING: None:: no matching candidate for image URI u'foo.*'
+WARNING: invalid pair index entry u''
 """
 
 HTML_XPATH = {
@@ -46,6 +51,9 @@ HTML_XPATH = {
         ".//img[@src='_images/img1.png']": '',
         ".//img[@src='_images/simg.png']": '',
     },
+    'subdir/images.html': {
+        ".//img[@src='../_images/img1.png']": '',
+    },
     'includes.html': {
         ".//pre/span[@class='s']": u'üöä',
         ".//pre": u'Max Strauß',
@@ -129,6 +137,32 @@ def test_latex(app):
            '\n'.join(difflib.ndiff(latex_warnings_exp.splitlines(),
                                    latex_warnings.splitlines()))
 
+    # only run latex if all needed packages are there
+    def kpsetest(filename):
+        try:
+            p = Popen(['kpsewhich', filename], stdout=PIPE)
+        except OSError, err:
+            # no kpsewhich... either no tex distribution is installed or it is
+            # a "strange" one -- don't bother running latex
+            return None
+        else:
+            p.communicate()
+            if p.returncode != 0:
+                # not found
+                return False
+            # found
+            return True
+
+    if kpsetest('article.sty') is None:
+        print >>sys.stderr, 'info: not running latex, it doesn\'t seem to be installed'
+        return
+    for filename in ['fancyhdr.sty', 'fancybox.sty', 'titlesec.sty', 'amsmath.sty',
+                     'framed.sty', 'color.sty', 'fancyvrb.sty', 'threeparttable.sty']:
+        if not kpsetest(filename):
+            print >>sys.stderr, 'info: not running latex, the %s package doesn\'t ' \
+                  'seem to be installed' % filename
+            return
+
     # now, try to run latex over it
     cwd = os.getcwd()
     os.chdir(app.outdir)
