@@ -13,7 +13,11 @@ import StringIO
 import tempfile
 import shutil
 
-from functools import wraps
+try:
+    from functools import wraps
+except ImportError:
+    # functools is new in 2.4
+    wraps = lambda f: (lambda w: w)
 
 from sphinx import application, builder
 
@@ -24,7 +28,7 @@ from nose import tools
 
 __all__ = [
     'test_root',
-    'raises', 'raises_msg',
+    'raises', 'raises_msg', 'Struct',
     'ListOutput', 'TestApp', 'with_app',
     'path', 'with_tempdir', 'write_file',
     'sprint',
@@ -66,6 +70,11 @@ def raises_msg(exc, msg, func, *args, **kwds):
                              (func.__name__, _excstr(exc)))
 
 
+class Struct(object):
+    def __init__(self, **kwds):
+        self.__dict__.update(kwds)
+
+
 class ListOutput(object):
     """
     File-like object that collects written text in a list.
